@@ -1,9 +1,10 @@
-import multiprocessing
 from conductor.client.automator.task_handler import TaskHandler
 from conductor.client.automator.task_runner import TaskRunner
 from conductor.client.configuration.configuration import Configuration
 from conductor.client.worker.sample.simple_python_worker import SimplePythonWorker
-from unittest.mock import MagicMock, Mock, patch
+from unittest.mock import Mock
+from unittest.mock import patch
+import multiprocessing
 import unittest
 
 
@@ -29,10 +30,10 @@ class TestTaskHandler(unittest.TestCase):
             )
             self.assertEqual(expected_exception, context.exception)
 
-    def test_start(self):
+    def test_start_processes(self):
         with patch.object(TaskRunner, 'run', PickableMock(return_value=None)):
             with self.__get_valid_task_handler() as task_handler:
-                task_handler.start()
+                task_handler.start_processes()
                 self.assertEqual(len(task_handler.task_runner_processes), 1)
                 for process in task_handler.task_runner_processes:
                     self.assertTrue(
@@ -42,5 +43,7 @@ class TestTaskHandler(unittest.TestCase):
     def __get_valid_task_handler(self):
         return TaskHandler(
             configuration=Configuration(),
-            workers=[SimplePythonWorker('task')]
+            workers=[
+                SimplePythonWorker('task')
+            ]
         )
